#!/usr/bin/python3
import sys
import glob
import json
import argparse

parser = argparse.ArgumentParser(description='Convert blast results to json documents')
parser.add_argument('--result', '-r', required=True, help='The blast result file in outfmt 7 format (tsv with headers)')
parser.add_argument('--output', '-o', required=True, help='The converted results json file')
parser.add_argument('--dbxref', '-d', required=True, help='The dbxref prefix that will be prepended to the accession or id')
args = parser.parse_args()

filename = args.result
documents = {}
with open(filename) as f:
    header = None
    tool = None
    for line in f:
        line = line.strip()
        if line.startswith('#'):
            if line.startswith('# Fields:'):
                header_entries = line.replace('# Fields: ','').split(', ')
                header = {}
                for idx, key in enumerate(header_entries):
                    header[key] = idx
            if line.startswith('# BLASTP'):
                split = line.split()
                tool = {'name': 'blastp',
                        'version': split[2]}
            if line.startswith('# Database'):
                split = line.split()
                tool['database'] = split[2]

        else:
            split = line.split("\t")
            if not split[0] in documents:
                documents[split[0]] = {"id": split[0], "computations": [{'tool':tool, 'results':[]}]}
            results = documents[split[0]]['computations'][0]['results']

            result = {'target':{}, 'query':{}}
            # check if subject id or accession exists
            sid = ''
            if 'subject id' in header:
                sid = header['subject id']
            elif 'subject acc.ver' in header:
                sid = header['subject acc.ver']
            else:
                raise Exception('No subject id found')


            result['target']["dbxref"] = args.dbxref + ':' + split[sid]
            if '% identity' in header:
                result['target']["percent_identity"] = float(split[header['% identity']])
            if 'q. start' in header and 'q. end' in header:
                result['query']['start'] = split[header['q. start']]
                result['query']['end'] = split[header['q. end']]
            if 's. start' in header and 's. end' in header:
                result['target']['start'] = split[header['s. start']]
                result['target']['end'] = split[header['s. end']]
            if 'evalue' in header:
                result['target']['evalue'] = float(split[header['evalue']])
            if 'BTOP' in header:
                result['target']['btop'] = split[header['BTOP']]

            results.append(result)

# add entries for files with no results
queries = []
path = "*.ids"
for filename in glob.glob(path):
    with open(filename) as f:
        for line in f:
            if line.startswith('>'):
                queries.append(line.split()[0].strip().lstrip('>'))
            else:
                queries.append(line.split()[0].strip())
for query_id in queries:
    if not query_id in documents:
        documents[query_id] = {"id": query_id, "computations": [{'tool': tool, 'results':[]}]}

output_filename = args.output
with open(output_filename, 'w') as o:
    json.dump(documents, o)
