#!/usr/bin/env python3

import sys
import json
import argparse
from os import path
import glob
import subprocess

parser = argparse.ArgumentParser(description='Convert ghostx results to json documents')
parser.add_argument('--result', '-r', required=True, help='The ghostx result directory')
parser.add_argument('--output', '-o', required=True, help='The converted results json file')
parser.add_argument('--dbxref', '-d', required=True, help='The dbxref prefix that will be prepended to the accession or id')
parser.add_argument('--acc_split', '-s', required=False, help='The delimiter used to split the subject id (optional)')
parser.add_argument('--acc_position', '-p', type=int, required=False, help='The position of the accession after splitting the subject_id (optional)')
args = parser.parse_args()

result_directory = args.result
info_filename = args.result + "/info.json"
result_filename = args.result + "/results.tsv"
documents = {}

tool = None
# read tool info
with open(info_filename) as f:
    tool = json.load(f)

with open(result_filename) as f:
    for line in f:
        line = line.strip()
        split = line.split("\t")
        # ghostx may contain the full fasta header as a query
        # remove everything after the actual id
        id = split[0].split()[0]
        if not id in documents:
            documents[id] = {"id": id, "computations": [{'tool':tool, 'results':[]}]}
        results = documents[id]['computations'][0]['results']

        result = {}
        accession = split[1]
        if args.acc_split and args.acc_position:
            accession = accession.split(args.acc_split)[args.acc_position]
        elif args.acc_split:
            accession = acession.split(args.acc_split)[0]
        result['query'] = {
                'start': split[6],
                'end': split[7]
                }
        result['target'] = {
                'dbxref': args.dbxref + ':' + accession,
                'start': split[8],
                'end': split[9],
                'evalue': float(split[10]),
                'percent_identity': float(split[2]),
                'score': float(split[11])
                }

        results.append(result)

# add entries for files with no results
queries = []
path = "*.ids"
for filename in glob.glob(path):
    with open(filename) as f:
        for line in f:
            if line.startswith('>'):
                queries.append(line.split()[0].strip().lstrip('>'))
            else:
                queries.append(line.split()[0].strip())
for query_id in queries:
    if not query_id in documents:
        documents[query_id] = {"id": query_id, "computations": [{'tool': tool, 'results':[]}]}

output_filename = args.output
with open(output_filename, 'w') as o:
    json.dump(documents, o)

