#!/usr/bin/python3
import sys
import json
import argparse
import glob

parser = argparse.ArgumentParser(description='Convert hmmscan results to json documents')
parser.add_argument('--result', '-r', required=True, help='The run_hmmer result directory')
parser.add_argument('--output', '-o', required=True, help='The converted results json file')
parser.add_argument('--dbxref', '-d', required=True, help='The dbxref prefix that will be prepended to the accession or id')
args = parser.parse_args()

# Provide a list of all query sequence names for conversion process
queries = []
path = "*.ids"
for filename in glob.glob(path):
    with open(filename) as f:
        for line in f:
            if line.startswith('>'):
                queries.append(line.split()[0].strip().lstrip('>'))
            else:
                queries.append(line.split()[0].strip())

filename = args.result + "/domtblout.tsv"
documents = {}
tool = {'name': None, 'version': None, 'database': None}
with open(filename) as f:
    # first scan for tool information
    for line in f:
        if line.startswith("# Program:"):
            tool['name'] = line.split()[2]
        if line.startswith("# Version:"):
            tool['version'] = line.split()[2]
        if line.startswith("# Target file:"):
            tool['database'] = line.split()[3]

with open(filename) as f:
    # second scan for data
    for line in f:
        if not line.startswith("#"):
            split = line.split(None, 22)
            query_id = split[3]
            if not query_id in documents:
                documents[query_id] = {"id": query_id, "computations": [{'tool': tool, 'results':[]}]}
                try:
                    queries.remove(query_id)
                except ValueError:
                    print('HMMER converter: Query ID "' + query_id + '" not found among initial queries!')
            results = documents[query_id]['computations'][0]["results"]

            dbxref = None
            if split[1] == "-":
                dbxref = args.dbxref + ":" + split[0]
            else:
                dbxref = args.dbxref + ":" + split[0]
            results.append({
                'target': {
                    'name': split[0], # target name
                    'dbxref': dbxref, 
                    'length': split[2], # tlen
                    'score': float(split[13]), # this domain score
                    'bias': float(split[14]), # this domain bias
                    'evalue': float(split[12]), # this domain i-Evalue
                    'start': int(split[15]), # hmm coord from
                    'end': int(split[16]), # hmm coord to
                    'acc': float(split[21]), # acc
                    'description': split[22].rstrip() # description of target
                    },
                'query': {
                    'start': int(split[17]), # ali coord from
                    'end': int(split[18]), # ali coord to
                    'envelop_start': int(split[19]), # env coord from
                    'envelop_end': int(split[20]) # env coord to
                    }
                })

for query_id in queries:
    if not query_id in documents:
        documents[query_id] = {"id": query_id, "computations": [{'tool': tool, 'results':[]}]}

output_filename = args.output
with open(output_filename, 'w') as o:
    json.dump(documents, o)
