#!/usr/bin/python3

import sys
import json
import argparse
from os import path

parser = argparse.ArgumentParser(description='Convert signalp results to json document')
parser.add_argument('--result', '-r', required=True, help='The signalp result directory')
parser.add_argument('--output', '-o', required=True, help='The converted results json file')
args = parser.parse_args()

mature_file = args.result + '/mature.fas'
include_mature = path.isfile(mature_file)
mature = {}

if include_mature:
    with open(mature_file) as m:
        id = None
        for line in m:
            if line.startswith(">"):
                id = line.split()[0][1:]
                mature[id] = ''
            elif id is not None:
                mature[id] += line.strip()

filename = args.result + '/results.txt'
documents = {}

with open(filename) as f:
    tool = None
    for line in f:
        if not line.startswith("#"):
            split = line.split()
            if not split[0] in documents:
                documents[split[0]] = {"id": split[0], "computations": [{'tool': tool, 'results':[]}]}
            results = documents[split[0]]['computations'][0]["results"]

            if split[9] == "Y":
                results.append({
                    'signalpeptide': True,
                    'score': float(split[8]),
                    'start': 1,
                    'end': int(split[2])-1
                    })

                if include_mature:
                    try:
                        results[-1]['mature sequence'] = mature[split[0]]
                    except ValueError:
                        print('SignalP Converter: No mature sequence received for protein {}, although signal peptide present!'.format(split[0]))
            else:
                results.append({'signalpeptide': False})
        else:
            if line.startswith('# SignalP'):
                split = line.split()
                tool = {'name': 'SignalP',
                        'version': split[1].split('-')[1],
                        'mode': split[2]}

output_filename = args.output

with open(output_filename, 'w') as o:
    json.dump(documents, o)
