#!/usr/bin/env python3

import sys
import json
import argparse
from os import path
import subprocess

parser = argparse.ArgumentParser(description='Convert targetp results to json document')
parser.add_argument('--result', '-r', required=True, help='The targetp results directory')
parser.add_argument('--output', '-o', required=True, help='The converted results json file')
args = parser.parse_args()

loc_dict = {"C": "chloroplast", "M": "mitochondrion", "S": "secretory pathway", "_": "other", "*": "undetermined"}

filename = args.result + '/results.txt'
documents = {}

with open(filename) as f:
    tool = None
    field_index = {"cTP": None, "mTP": None, "SP": None, "Loc": None}
    is_datasection = False

    for line in f:
        if line.startswith("---------"):
            is_datasection = not is_datasection
        elif is_datasection:
            split = line.split()
            if not split[0] in documents:
                documents[split[0]] = {"id": split[0], "computations": [{'tool': tool, 'results':[{}]}]}
                results = documents[split[0]]['computations'][0]["results"][0]
                for field in field_index:
                    if field_index[field] is not None:
                        if field == "Loc":
                            results['Localization'] = loc_dict[split[field_index[field]]]
                        else:
                            results[field] = float(split[field_index[field]])
        else:
            if line.startswith('Name   '):
                split = line.split()
                for field in field_index:
                    try:
                        field_index[field] = split.index(field)
                    except ValueError:
                        print('TargetP Converter: No column "' + field + '" found in table!')
            elif line.startswith('### targetp '):
                split = line.split()
                tool = {'name': 'TargetP',
                        'version': split[2].replace("v", ""),
                        'organism_group': 'plant'}
            elif ' NON-PLANT ' in line:
                tool['organism_group'] = 'non-plant'

output_filename = args.output

with open(output_filename, 'w') as o:
    json.dump(documents, o)

