#!/usr/bin/python3

import sys
import json
import argparse

parser = argparse.ArgumentParser(description='Convert tmhmm results to json documents')
parser.add_argument('--result', '-r', required=True, help='The tmhmm result file')
parser.add_argument('--output', '-o', required=True, help='The converted results json file')
args = parser.parse_args()

def parse_topology(s, l):
  elements = []
  result = []
  flag = False
  num = ""
  for c in s:
    if c == 'i' or c == 'o' or c == '-':
      if num != "":
        elements.append(int(num))
        num = ""
      if c != '-':
        elements.append(c)
    else:
      num += c
  if num != "":
    elements.append(int(num))
  for i in range(len(elements)):
    if flag:
      flag = False
    else:
      if elements[i] == 'i' or elements[i] == 'o':
        location = ""
        if elements[i] == 'i':
          location = "inside"
        else:
          location = "outside"
        if i == 0:
          if len(elements) == 1:
            result.append({'start': 1, 'end': l , 'location': location})
          else:
            result.append({'start': 1, 'end': elements[i+1]-1 , 'location': location})
        elif i+1 == len(elements):
          result.append({'start': elements[i-1]+1, 'end':l , 'location': location})
        else:
          result.append({'start': elements[i-1]+1, 'end': elements[i+1]-1 , 'location': location})
      else:
        result.append({'start': elements[i], 'end': elements[i+1] , 'location': 'membrane'})
        flag = True
  return (result)

filename = args.result
documents = {}
with open(filename) as f:
  for line in f:
    line_dic = {}
    elements = line.rstrip().split("\t")
    for i in range(1, len(elements)):
      key = elements[i][:elements[i].rfind('=')]
      value = elements[i][elements[i].rfind('=')+1:]
      if key == 'Topology':
        line_dic['topology'] = parse_topology(value, int(elements[i-4][elements[i-4].rfind('=')+1:]))
      elif key == 'PredHel':
        line_dic[key] = int(value)
      elif not key == 'len':
        line_dic[key] = float(value)
    documents[elements[0]] = {'computations': [{'tool': {'name': 'TMHMM', 'version': '2.0'}, 'results': [line_dic]}]}

output_filename = args.output
with open(output_filename, 'w') as o:
  json.dump(documents, o)
