#! /bin/bash

LOGFILE=$1
DATADIR=$2
#s3 bucket from which the databases are downloaded
S3BUCKET='psot-databases'
# list of database folders, downloaded as tar-archives
list='ghostx uniprot pfam-31'

function make_datadir_and_sync () {
  
  echo "Synchronizing databases because of first run"
  mkdir -p $DATADIR
  sync_data "$list"
}

function test_datadir () {

  if ! [[ -e $DATADIR && -d $DATADIR ]]; then
  
    echo "Could not find databases in config given path"
    mkdir -p $DATADIR
    sync_data "$list"
    
  elif ! all_folders_in_datadir "test_true"; then
  
    echo "Missing databases in config given path"
    sync_data "$(all_folders_in_datadir 'return_missing')"
    
  fi
}

function all_folders_in_datadir () {

  new_list=""

  for ele in $list; do
    if ! $(ls $DATADIR | grep -qx "$ele"); then
      if [ $1 == "test_true" ]; then
        return 1
      else
        new_list="$new_list $ele"
      fi
    fi
  done

  if [ $1 == "test_true" ]; then
    return 0
  else
    echo "$new_list"
  fi
}

function sync_data () {
  
  [[ -r $DATADIR && -w $DATADIR && -x $DATADIR ]] || \
  fail "ERROR: database directory must be readable, writable and executable"

  cd $DATADIR

  if [[ -e lockfile ]]; then
    echo "Database directory is locked. Waiting for lockfile to be removed..."
    while [[ -e lockfile ]]; do
      sleep 5
    done
    exit 0
  else
    echo "[$(date)] lockfile created from psot (PID $$)" > lockfile
    
    download_list=$1
    
    echo "Downloading databases... "
    for ele in $download_list; do
      wget -q "https://${S3BUCKET}.s3.computational.bio.uni-giessen.de/${ele}.tar.gz"
      tar -zxf "${ele}.tar.gz"
      rm "${ele}.tar.gz"
    done
  
    ln -s -f 'pfam-31/' 'pfam'
    
    echo "[$(date)] psot (PID $$) downloaded databases to $DATADIR" >> $LOGFILE
    
    rm lockfile
  fi
}

function fail () {
  echo >&2 "$1"
  exit 1
}

[ "$#" -eq 2 ] || fail "ERROR: 2 arguments required, $# provided"

if [[ -e $LOGFILE ]]; then
  test_datadir
else
  make_datadir_and_sync
  echo "[$(date)] logfile created from psot (PID $$)" > $LOGFILE
fi
