#!/usr/bin/env python3

import json
import argparse

parser = argparse.ArgumentParser(description='Join json documents')
parser.add_argument('jsons', metavar='N', nargs='+', help='json documents')
parser.add_argument('--output', '-o', required=True, help='The name of the output document')
args = parser.parse_args()

def extend(m, o):
    for key in o:
        if key not in m:
            m[key] = o[key]
        else:
            if type(o[key]) is list:
                m[key].extend(o[key])
            if type(o[key]) is dict:
                m[key].update(o[key])


joined = {}
for file in args.jsons:
    with open(file) as f:
        doc = json.load(f)
        for k in doc:
            if not k in joined:
                joined[k] = {'id': k, 'computations':[]}
            extend(joined[k], doc[k])

output_filename = args.output
with open(output_filename, 'w') as o:
    json.dump(joined, o)
