#!/usr/bin/python3

import json
import argparse
from os.path import splitext

parser = argparse.ArgumentParser(description='Replaces the sequence identifiers in a json document with the id from the mapping file')
parser.add_argument('--json', '-j', required=True, help='The json document file')
parser.add_argument('--tsv', '-t', required=True, help='The mapping file in tsv format')
parser.add_argument('--output', '-o', required=True, help='The result json document file')
args = parser.parse_args()

id_to_description = {}
seq_id_dict = {}
docs_enumerated = {}

# read documents
with open(args.json) as j:
    docs_enumerated = json.load(j)

# read mapping
with open(args.tsv) as h:
    for line in h:
        split = line.strip().split('\t')
        num, id = (split[0], split[1])
        seq_id_dict[num] = id
        if len(split) is 3:
            description = split[2]
            id_to_description[id] = description

documents_restored = {}

for num in docs_enumerated:
    seq_id = seq_id_dict[num]
    doc = docs_enumerated[num]
    doc["id"] = seq_id
    if seq_id in id_to_description:
        doc["description"] = id_to_description[seq_id]
    documents_restored[seq_id] = doc

with open(args.output, 'w') as o:
    json.dump(documents_restored, o)
