#!/usr/bin/env python3

import json
import argparse
import os
import os.path

parser = argparse.ArgumentParser(description='Split a json file with multiple documents into single files per document')
parser.add_argument('--json', '-j', required=True, help='json documents')
parser.add_argument('--tool', '-t', help='The name of the tool with which the results were generated')
parser.add_argument('--output', '-o', required=True, help='The name of the output directory')
args = parser.parse_args()

# check if output directory exists and create it if not
output_dir = os.path.abspath(args.output)
if os.path.exists(output_dir) and not os.path.isdir(output_dir):
    print("Output " + output_dir + " exists and is not a directory")
    exit(1)
if not os.path.exists(output_dir):
    os.mkdir(output_dir)

file = args.json
with open(file) as f:
    doc = json.load(f)
    for k in doc:
        if args.tool:
            output_filename = k + "." + args.tool + '.json'
        else:
            output_filename = k + '.json'
        with open(output_dir + '/' + output_filename, 'w') as o:
            json.dump(doc[k], o)
