import unittest
import pkg_resources
from tempfile import TemporaryDirectory
from subprocess import run
import os.path
import json

class TestPsot(unittest.TestCase):

    def test_that_psot_fails_if_input_file_does_not_exist(self):
        proc = run(["psot", 'analyze', '-f', 'file', '-o', 'temporary output directory', '-p', 'fast'])
        self.assertNotEqual(proc.returncode, 0)

    def test_that_psot_runs(self):
        profiles = ['fast', 'common', 'complete']
        modes = [None, '--use_cluster', '--docker', '--singularity']
        testdata = pkg_resources.resource_filename('tests', 'data/single.fas')
        for mode in modes:
          for profile in profiles:
            with self.subTest(profile=profile, mode=mode):
              with TemporaryDirectory() as result_directory:
                  command = ["psot", 'analyze', '-f', testdata, '-o', result_directory, '-p', profile]
                  if mode is not None:
                      command.append(mode)
                  proc = run(command)
                  # first check if the result file exists
                  expected_file = result_directory +'/seq_1.cds_10.json'
                  self.assertTrue(os.path.exists(expected_file))
                  # now check if it is a valid json and contains the id and a non-empty list of results
                  with open(expected_file, 'r') as f:
                    result = json.load(f)
                    self.assertTrue('id' in result)
                    self.assertTrue('computations' in result)
                    self.assertGreater(len(result['computations']), 0)
