#!/usr/bin/python3

import argparse
from os.path import splitext

parser = argparse.ArgumentParser(description='''Simplifies the headers from a fasta file, by replacing the ids with 
                                 consecutive numbers and removing everything else from the header. Additionally a 
                                 mapping file is created in order to retrieve the original ids.''')
parser.add_argument('--fasta', '-f', required=True, help='The fasta file')
parser.add_argument('--tsv', '-t', required=True, help='Tab separated file with a mapping from simplified ids to original ids')
parser.add_argument('--output', '-o', required=True, help='The fasta file with simplified headers')
args = parser.parse_args()

headers_dict = {}
num = 1

# write simplified fasta
with open(args.fasta) as f:
  with open(args.output, mode='w') as w:
    for line in f:
        line = line.strip()
        if line.startswith(">"):
            s = line.split(" ", 1)
            id = s[0].lstrip(">")
            rest = s[1] if len(s) > 1 else ""
            headers_dict[num] = {'id': id, 'rest': rest}
            print(">{}".format(num), file=w)
            num += 1
        else:
            print(line, file=w)

# write id mapping as tsv
with open(args.tsv, 'w') as o:
    for key in headers_dict:
        o.write("{}\t{}\t{}\n".format(key, headers_dict[key]['id'], headers_dict[key]['rest']))
